==> kubernetes-model-apiextensions-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceValidationFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class CustomResourceValidationFluentImpl<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent<A>{
  public CustomResourceValidationFluentImpl() {
  }
  public CustomResourceValidationFluentImpl(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation instance) {
    this.withOpenAPIV3Schema(instance.getOpenAPIV3Schema()); 
  }
  private io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder openAPIV3Schema;
  
  /**
   * This method has been deprecated, please use method buildOpenAPIV3Schema instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps getOpenAPIV3Schema() {
    return this.openAPIV3Schema!=null?this.openAPIV3Schema.build():null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildOpenAPIV3Schema() {
    return this.openAPIV3Schema!=null?this.openAPIV3Schema.build():null;
  }
  public A withOpenAPIV3Schema(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps openAPIV3Schema) {
    _visitables.get("openAPIV3Schema").remove(this.openAPIV3Schema);
    if (openAPIV3Schema!=null){ this.openAPIV3Schema= new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder(openAPIV3Schema); _visitables.get("openAPIV3Schema").add(this.openAPIV3Schema);} return (A) this;
  }
  public java.lang.Boolean hasOpenAPIV3Schema() {
    return this.openAPIV3Schema != null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> withNewOpenAPIV3Schema() {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluentImpl.OpenAPIV3SchemaNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> withNewOpenAPIV3SchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item) {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluentImpl.OpenAPIV3SchemaNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> editOpenAPIV3Schema() {
    return withNewOpenAPIV3SchemaLike(getOpenAPIV3Schema());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> editOrNewOpenAPIV3Schema() {
    return withNewOpenAPIV3SchemaLike(getOpenAPIV3Schema() != null ? getOpenAPIV3Schema(): new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> editOrNewOpenAPIV3SchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item) {
    return withNewOpenAPIV3SchemaLike(getOpenAPIV3Schema() != null ? getOpenAPIV3Schema(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CustomResourceValidationFluentImpl that = (CustomResourceValidationFluentImpl) o;
    if (openAPIV3Schema != null ? !openAPIV3Schema.equals(that.openAPIV3Schema) :that.openAPIV3Schema != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(openAPIV3Schema,  super.hashCode());
  }
  public class OpenAPIV3SchemaNestedImpl<N> extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent.OpenAPIV3SchemaNested<N>> implements io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent.OpenAPIV3SchemaNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    OpenAPIV3SchemaNestedImpl(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item) {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder(this, item);
    }
    OpenAPIV3SchemaNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder(this);
    }
    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder builder;
    public N and() {
      return (N) CustomResourceValidationFluentImpl.this.withOpenAPIV3Schema(builder.build());
    }
    public N endOpenAPIV3Schema() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-apiextensions-5.10.1-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceValidationFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class CustomResourceValidationFluentImpl<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent<A>{
  public CustomResourceValidationFluentImpl() {
  }
  public CustomResourceValidationFluentImpl(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation instance) {
    this.withOpenAPIV3Schema(instance.getOpenAPIV3Schema()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder openAPIV3Schema;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildOpenAPIV3Schema instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps getOpenAPIV3Schema() {
    return this.openAPIV3Schema!=null?this.openAPIV3Schema.build():null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildOpenAPIV3Schema() {
    return this.openAPIV3Schema!=null?this.openAPIV3Schema.build():null;
  }
  public A withOpenAPIV3Schema(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps openAPIV3Schema) {
    _visitables.get("openAPIV3Schema").remove(this.openAPIV3Schema);
    if (openAPIV3Schema!=null){ this.openAPIV3Schema= new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder(openAPIV3Schema); _visitables.get("openAPIV3Schema").add(this.openAPIV3Schema);} return (A) this;
  }
  public java.lang.Boolean hasOpenAPIV3Schema() {
    return this.openAPIV3Schema != null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> withNewOpenAPIV3Schema() {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluentImpl.OpenAPIV3SchemaNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> withNewOpenAPIV3SchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item) {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluentImpl.OpenAPIV3SchemaNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> editOpenAPIV3Schema() {
    return withNewOpenAPIV3SchemaLike(getOpenAPIV3Schema());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> editOrNewOpenAPIV3Schema() {
    return withNewOpenAPIV3SchemaLike(getOpenAPIV3Schema() != null ? getOpenAPIV3Schema(): new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> editOrNewOpenAPIV3SchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item) {
    return withNewOpenAPIV3SchemaLike(getOpenAPIV3Schema() != null ? getOpenAPIV3Schema(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CustomResourceValidationFluentImpl that = (CustomResourceValidationFluentImpl) o;
    if (openAPIV3Schema != null ? !openAPIV3Schema.equals(that.openAPIV3Schema) :that.openAPIV3Schema != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(openAPIV3Schema,  additionalProperties,  super.hashCode());
  }
  public class OpenAPIV3SchemaNestedImpl<N> extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent.OpenAPIV3SchemaNested<N>> implements io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent.OpenAPIV3SchemaNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    OpenAPIV3SchemaNestedImpl(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item) {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder(this, item);
    }
    OpenAPIV3SchemaNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder(this);
    }
    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder builder;
    public N and() {
      return (N) CustomResourceValidationFluentImpl.this.withOpenAPIV3Schema(builder.build());
    }
    public N endOpenAPIV3Schema() {
      return and();
    }
    
  }
  
}
